# About

## Development

Plopp is an open source project by the [European Spallation Source ERIC](https://europeanspallationsource.se/) (ESS).

## License

Plopp is available as open source under the [BSD-3 license](https://opensource.org/licenses/BSD-3-Clause).

## Citing Plopp

Please cite the following:

[![DOI](https://zenodo.org/badge/528859752.svg)](https://zenodo.org/badge/latestdoi/528859752)

To cite a specific version of Plopp, select the desired version on Zenodo to get the corresponding DOI.

## Older versions of the documentation

Older versions of the documentation pages can be found under the assets of each [release](https://github.com/scipp/plopp/releases).
Simply download the archive, unzip and view locally in a web browser.

## Source code and development

Plopp is hosted and developed [on GitHub](https://github.com/scipp/plopp).

## Contributing to Plopp

Contributions, bug reports, and ideas are always welcome.
If in doubt whether a feature falls within the scope of Plopp please [ask on GitHub](https://github.com/scipp/plopp/issues) before implementing functionality, to reduce the risk of rejected pull requests.
Asking and discussing first is generally always a good idea, since our road map is not very mature at this point.
